#! Flux2D 11.2


#executeBatchSpy('buildGeomesh.py')

lastInstance = ApplicationMagneticDC2D(domain2D=Domain2DPlane(lengthUnit=LengthUnit['MILLIMETER'],
                                       depth='THICKNESS'),
                                       solverFE=SolverFEFlux3D(),
                                       coilCoefficient=CoilCoefficientAutomatic())

lastInstance = VariationParameterFormula(name='NP',
                                         formula='4000')

lastInstance = VariationParameterFormula(name='NS',
                                         formula='1000')

lastInstance = VariationParameterFormula(name='I_MAX',
                                         formula='1')

lastInstance = VariationParameterPilot(name='ALPHA',
                                       referenceValue=0.1)

lastInstance = VariationParameterFormula(name='JS',
                                         formula='1.2')

lastInstance = VariationParameterFormula(name='MUR',
                                         formula='500')

lastInstance = CurrentStrandedCoil(name='PRIMARY_FIELD',
                                   rmsModulus='ALPHA*I_MAX')

lastInstance = Material(name='MATERIAL',
                        propertyBH=PropertyBhNonlinearJmu(initialMur='MUR',
                        js='JS'))

lastInstance = RegionFace(name='AIR',
                          magneticDC2D=MagneticDC2DFaceVacuum(),
                          color=Color['White'],
                          visibility=Visibility['VISIBLE'])

lastInstance = RegionFace(name='MAGNETIC_CIRCUIT',
                          magneticDC2D=MagneticDC2DFaceMagnetic(material=Material['MATERIAL']),
                          color=Color['Cyan'],
                          visibility=Visibility['VISIBLE'])

lastInstance = RegionFace(name='PRIMARY_COIL_PLUS',
                          magneticDC2D=MagneticDC2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='NP',
                          seriesParallel=AllInSeries(),
                          electricComponent=CoilConductor['PRIMARY_FIELD'])),
                          color=Color['Red'],
                          visibility=Visibility['VISIBLE'])

lastInstance = RegionFace(name='PRIMARY_COIL_MINUS',
                          magneticDC2D=MagneticDC2DFaceCoilConductor(coilConductor=CoilConductor2DNegative(turnNumber='NP',
                          seriesParallel=AllInSeries(),
                          electricComponent=CoilConductor['PRIMARY_FIELD'])),
                          color=Color['Yellow'],
                          visibility=Visibility['VISIBLE'])

startMacroTransaction()
RegionFace['INFINITE'].magneticDC2D = MagneticDC2DFaceVacuum()

RegionFace['INFINITE'].visibility = Visibility['VISIBLE']

endMacroTransaction()

lastInstance = CurrentStrandedCoil(name='SECONDARY_COIL',
                                   rmsModulus='0')

lastInstance = RegionLine(name='SEC_PLUS',
                          magneticDC2D=MagneticDC2DLineCoilConductor(thickness='1e-3',
                          coilConductor=CoilConductor2DPositive(turnNumber='NS',
                          seriesParallel=AllInSeries(),
                          electricComponent=CoilConductor['SECONDARY_COIL'])),
                          color=Color['Magenta'],
                          visibility=Visibility['VISIBLE'])

lastInstance = RegionLine(name='SEC_MINUS',
                          magneticDC2D=MagneticDC2DLineCoilConductor(thickness='1E-3',
                          coilConductor=CoilConductor2DNegative(turnNumber='NS',
                          seriesParallel=AllInSeries(),
                          electricComponent=CoilConductor['SECONDARY_COIL'])),
                          color=Color['Magenta'],
                          visibility=Visibility['VISIBLE'])

assignRegionToFaces(face=[Face[17],
                    Face[8],
                    Face[2],
                    Face[10],
                    Face[9]],
                    region=RegionFace['AIR'])

assignRegionToFaces(face=[Face[11],
                    Face[3],
                    Face[12],
                    Face[13]],
                    region=RegionFace['MAGNETIC_CIRCUIT'])

assignRegionToFaces(face=[Face[1],
                    Face[5],
                    Face[6],
                    Face[7]],
                    region=RegionFace['PRIMARY_COIL_MINUS'])

assignRegionToFaces(face=[Face[4],
                    Face[14],
                    Face[15],
                    Face[16]],
                    region=RegionFace['PRIMARY_COIL_PLUS'])

Line[15, 16, 19, 2].assignRegion(region=RegionLine['SEC_MINUS'])

Line[24, 25, 27, 3].assignRegion(region=RegionLine['SEC_PLUS'])

saveProjectAs('physbuilt.FLU')

